@@ -21,12 +21,17 @@ Name of the Availability Zone.
 
 State of the Availability Zone. 
 
+=item region_name (required)
+
+Name of the region.
+
 =back
 
 =cut
 
 has 'zone_name'		=> ( is => 'ro', isa => 'Str', required => 1 );
 has 'zone_state'	=> ( is => 'ro', isa => 'Str', required => 1 );
+has 'region_name'	=> ( is => 'ro', isa => 'Str', required => 1 );
 
 __PACKAGE__->meta->make_immutable();
 
@@ -36,7 +41,7 @@ Jeff Kim <jkim@chosec.com>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2006-2008 Jeff Kim. This program is free software; you can redistribute it and/or modify it
+Copyright (c) 2006-2009 Jeff Kim. This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
 
 =cut
